@@ -1,11 +1,15 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from . import pg
 from .command import do_command
 from .get import get_inspector
 from .inspected import ColumnInfo, Inspected
 from .inspector import DBInspector, NullInspector, to_pytype
 
+try:
+    from graphlib import TopologicalSorter  # noqa
+except ImportError:
+    from .graphlib import TopologicalSorter  # noqa
+
+
 __all__ = [
     "DBInspector",
     "to_pytype",
